@@ -1,7 +1,6 @@
-#!/usr/bin/python
 # encoding=UTF-8
 
-# Copyright © 2007, 2008, 2009 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2007-2019 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -21,16 +20,15 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-
-'''Parse and generate DIME messages.
-
-DIME specification: <http://xml.coverpages.org/draft-nielsen-dime-02.txt>.
+'''
+parse and generate DIME messages
 '''
 
+import struct as _struct
+
 __author__ = 'Jakub Wilk <jwilk@jwilk.net>'
-__version__ = '0.2.1'
-__all__ = \
-[
+__version__ = '0.3'
+__all__ = [
     'Message',
     'Record',
     'Type',
@@ -44,8 +42,6 @@ __all__ = \
 
 SOAP_NS = 'http://schemas.xmlsoap.org/soap/envelope/'
 
-import struct as _struct
-
 def _typecheck_str(value, bits):
     if not isinstance(value, str):
         raise TypeError()
@@ -58,20 +54,21 @@ def _typecheck_int(value, bits):
     if not (0 <= value < (1 << bits)):
         raise ValueError()
 
-def _typecheck(value, klass):
-    if not isinstance(value, klass):
+def _typecheck(value, cls):
+    if not isinstance(value, cls):
         raise ValueError()
 
 class Type(object):
 
-    '''Please don't subclass Type, unless you know what you're doing.
-    Please don't isntantiate Type. Instead, use one of its subclasses.'''
+    '''
+    abstract payload type class
+    '''
 
-    def __init__(self, value = ''):
+    def __init__(self, value=''):
         if self.__class__ == Type:
             raise TypeError(
                 '''Please use one of the Type's subclasses: %s.''' %
-                ', '.join(klass.__name__ for klass in Type.__subclasses__())
+                ', '.join(cls.__name__ for cls in Type.__subclasses__())
             )
         _typecheck_str(value, 16)
         try:
@@ -81,24 +78,25 @@ class Type(object):
             pass
         self.tnf = self._code
         self.value = value
-    
+
     @staticmethod
     def load_string(tnf, value):
         _typecheck_int(tnf, 4)
-        for klass in Type.__subclasses__():
-            if klass._code == tnf:
-                return klass(value)
+        for cls in Type.__subclasses__():
+            if cls._code == tnf:
+                return cls(value)
         return UnsupportedType(tnf, value)
-    
+
     def as_mime(self):
-        from email.MIMEBase import MIMEBase
+        from email.mime.base import MIMEBase
         return MIMEBase('application', 'octet-stream')
 
 class UnchangedType(Type):
 
-    '''This type must be used in all middle record chunks and terminating
-    record chunks used in chunked payloads.
-    It must not be used in any other record.'''
+    '''
+    payload type to be used in middle record chunks and terminating record
+    chunks used in chunked payloads
+    '''
 
     _code = 0x00
     require_empty_value = True
@@ -108,7 +106,7 @@ class UnchangedType(Type):
 
 class MediaType(Type):
 
-    '''A type which is identified by a media type construct.'''
+    '''payload type identified by media type construct'''
 
     _code = 0x01
 
@@ -116,13 +114,13 @@ class MediaType(Type):
         return self.value
 
     def as_mime(self):
-        from email.MIMEBase import MIMEBase
+        from email.mime.base import MIMEBase
         maintype, subtype = self.value.split('/')
         return MIMEBase(maintype, subtype)
 
 class TypeByUri(Type):
-    
-    '''A type which is identified by a URI construct.'''
+
+    '''type identified by a URI construct'''
 
     _code = 0x02
 
@@ -130,7 +128,7 @@ class TypeByUri(Type):
         return self.value
 
     def as_mime(self):
-        from email.MIMEBase import MIMEBase
+        from email.mime.base import MIMEBase
         if self.value == SOAP_NS:
             return MIMEBase('text', 'xml')
         else:
@@ -138,7 +136,7 @@ class TypeByUri(Type):
 
 class UnknownType(Type):
 
-    '''Indicate that type of the payload is unknown.'''
+    '''indicate that type of the payload is unknown'''
 
     _code = 0x03
     require_empty_value = True
@@ -148,7 +146,7 @@ class UnknownType(Type):
 
 class NoneType(Type):
 
-    '''Indicate that there is no type or payload associated with this record.'''
+    '''indicate that there is no type or payload associated with the record'''
 
     _code = 0x04
     require_empty_value = True
@@ -158,14 +156,14 @@ class NoneType(Type):
 
 class UnsupportedType(Type):
 
-    '''An unsupported type.'''
+    '''unsupported type'''
 
     _code = None
 
     def __init__(self, tnf, value):
         Type.__init__(self, value)
         self.tnf = tnf
-    
+
     def __str__(self):
         return '<unsupported>'
 
@@ -181,7 +179,7 @@ def _write4(stream, value):
 def _write_padded(stream, value):
     stream.write(value)
     stream.write('\0' * (4 - len(value) & 3))
-    
+
 def _read1(stream):
     value, = _struct.unpack('>B', stream.read(1))
     return value
@@ -211,7 +209,7 @@ class Record(object):
     class UnsupportedVersion(Exception):
         pass
 
-    def __init__(self, id = None, type = DEFAULT_TYPE, data = '', mb = 0, me = 0, cf = 0, version = DEFAULT_VERSION):
+    def __init__(self, id=None, type=DEFAULT_TYPE, data='', mb=0, me=0, cf=0, version=DEFAULT_VERSION):
         if id is None:
             from uuid import uuid4
             id = 'uuid:%s' % uuid4()
@@ -237,11 +235,11 @@ class Record(object):
         return '%s with id=%s, type=%s, flags=%s>' % (head, repr(self.id), self.type, flags)
 
     def save(self, stream):
-        dose = self.cf | self.me << 1 | self.mb << 2 | self.version << 3;
+        dose = self.cf | self.me << 1 | self.mb << 2 | self.version << 3
         _write1(stream, dose)
-        dose = self.type.tnf << 4;
+        dose = self.type.tnf << 4
         _write1(stream, dose)
-        options = '' # options are not supported
+        options = ''  # options are not supported
         for q in (options, self.id, self.type.value):
             _write2(stream, len(q))
         _write4(stream, len(self.data))
@@ -266,12 +264,12 @@ class Record(object):
         type_length = _read2(stream)
         data_length = _read4(stream)
         options = _read_padded(stream, options_length)
-        del options # options are not supported
+        del options  # options are not supported
         id = _read_padded(stream, id_length)
         type = _read_padded(stream, type_length)
         data = _read_padded(stream, data_length)
         return Record(id, Type.load_string(tnf, type), data, mb, me, cf, version)
-    
+
     @staticmethod
     def load_all(stream):
         while True:
@@ -281,7 +279,7 @@ class Record(object):
                 break
 
     def as_mime(self):
-        from email.Encoders import encode_7or8bit as encode
+        from email.encoders import encode_7or8bit as encode
         attachment = self.type.as_mime()
         attachment.set_payload(self.data)
         attachment['Content-Length'] = str(len(self.data))
@@ -294,14 +292,14 @@ class Message(object):
     def __init__(self, records):
         self.records = list(records)
         self.dict = dict((record.id, record) for record in self.records)
-    
+
     def __repr__(self):
         head = object.__repr__(self).split(' object ')[0]
         return '%s with records=%s>' % (head, self.records)
 
     @staticmethod
     def load(stream):
-        return Message(records = Record.load_all(stream))
+        return Message(records=Record.load_all(stream))
 
     def __getitem__(self, key):
         if isinstance(key, int):
@@ -325,7 +323,7 @@ class Message(object):
             record.save(stream)
 
     def as_mime(self):
-        from email.MIMEMultipart import MIMEMultipart
+        from email.mime.multipart import MIMEMultipart
         message = MIMEMultipart()
         message.preamble = 'This is a multi-part message in MIME format. It was automatically converted from a DIME message.\n'
         message.epilogue = ''
@@ -333,4 +331,4 @@ class Message(object):
             message.attach(record.as_mime())
         return message
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
